device: Rename scan_static_bus() -> enable_static_devices()

The new name should reflect better what this function does, as that
is only one specific step of the scanning.

Change-Id: I9c9dc437b6117112bb28550855a2c38044dfbfa5
Signed-off-by: Nico Huber <nico.huber@secunet.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/31900
Reviewed-by: Felix Held <felix-coreboot@felixheld.de>
Reviewed-by: Kyösti Mälkki <kyosti.malkki@gmail.com>
Reviewed-by: Patrick Rudolph <siro@das-labor.org>
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
diff --git a/src/include/device/device.h b/src/include/device/device.h
index 991bd38..96fc837 100644
--- a/src/include/device/device.h
+++ b/src/include/device/device.h
@@ -327,9 +327,9 @@
 	return config_of(pcidev_on_root(0, 0));
 }
 
+void enable_static_devices(struct device *bus);
 void scan_smbus(struct device *bus);
 void scan_generic_bus(struct device *bus);
-void scan_static_bus(struct device *bus);
 void scan_lpc_bus(struct device *bus);
 void scan_usb_bus(struct device *bus);
 
diff --git a/src/soc/intel/common/block/dsp/dsp.c b/src/soc/intel/common/block/dsp/dsp.c
index d268893..277b6c5 100644
--- a/src/soc/intel/common/block/dsp/dsp.c
+++ b/src/soc/intel/common/block/dsp/dsp.c
@@ -23,7 +23,7 @@
 	.set_resources          = pci_dev_set_resources,
 	.enable_resources       = pci_dev_enable_resources,
 	.ops_pci                = &pci_dev_ops_pci,
-	.scan_bus               = scan_static_bus,
+	.scan_bus               = enable_static_devices,
 };
 
 static const unsigned short pci_device_ids[] = {
diff --git a/src/soc/intel/common/block/hda/hda.c b/src/soc/intel/common/block/hda/hda.c
index 0cf9baa..be8319c 100644
--- a/src/soc/intel/common/block/hda/hda.c
+++ b/src/soc/intel/common/block/hda/hda.c
@@ -68,7 +68,7 @@
 	.init			= hda_init,
 #endif
 	.ops_pci		= &pci_dev_ops_pci,
-	.scan_bus		= scan_static_bus,
+	.scan_bus		= enable_static_devices,
 };
 
 static const unsigned short pci_device_ids[] = {
diff --git a/src/superio/common/generic.c b/src/superio/common/generic.c
index 96307a3..76122a1 100644
--- a/src/superio/common/generic.c
+++ b/src/superio/common/generic.c
@@ -187,7 +187,7 @@
 	 * Need to call enable_dev() on the devices "behind" the Generic Super I/O.
 	 * coreboot's generic allocator doesn't expect them behind PnP devices.
 	 */
-	scan_static_bus(dev);
+	enable_static_devices(dev);
 }
 
 struct chip_operations superio_common_ops = {
diff --git a/src/device/root_device.c b/src/device/root_device.c
index beeead2..0580914 100644
--- a/src/device/root_device.c
+++ b/src/device/root_device.c
@@ -19,7 +19,7 @@
 const char mainboard_name[] = CONFIG_MAINBOARD_VENDOR " " CONFIG_MAINBOARD_PART_NUMBER;
 
 /**
  * Scan devices on static buses.
  *
  * The enumeration of certain buses is purely static. The existence of
  * devices on those buses can be completely determined at compile time
@@ -36,7 +36,7 @@
  * @param bus Pointer to the device to which the static buses are attached to.
  */
 
-void scan_static_bus(struct device *bus)
+void enable_static_devices(struct device *bus)
 {
 	struct device *child;
 	struct bus *link;
@@ -60,7 +60,7 @@
 {
 	printk(BIOS_SPEW, "%s for %s\n", __func__, dev_path(bus));
 
-	scan_static_bus(bus);
+	enable_static_devices(bus);
 
 	printk(BIOS_SPEW, "%s for %s done\n", __func__, dev_path(bus));
 }
@@ -71,7 +71,7 @@
 
 	printk(BIOS_SPEW, "%s for %s\n", __func__, dev_path(bus));
 
-	scan_static_bus(bus);
+	enable_static_devices(bus);
 
 	/* Scan bridges in case this device is a hub */
 	for (link = bus->link_list; link; link = link->next)
@@ -129,7 +129,7 @@
 
 	printk(BIOS_SPEW, "%s for %s\n", __func__, dev_path(bus));
 
-	scan_static_bus(bus);
+	enable_static_devices(bus);
 
 	for (link = bus->link_list; link; link = link->next)
 		scan_bridges(link);
@@ -19,7 +19,7 @@
 
 /**
- * Scan devices on static buses.
+ * Enable devices on static buses.
  *
  * The enumeration of certain buses is purely static. The existence of